@@ -1,21 +1,33 @@
-from typing import Callable, List, Tuple, Any, Union
-import numpy as np
+"""
+This contains all the statistical functions.
+"""
+
+# pylint: disable=too-many-arguments
+
 import logging
-from yupi.trajectory import Trajectory
-from yupi.vector import Vector
-from yupi.transformations import subsample
+from typing import Callable, List, Optional, Tuple, Union
+
+import numpy as np
+
 from yupi._checkers import (
-    _check_uniform_time_spaced,
-    _check_same_dt,
-    _check_same_dim,
-    _check_exact_dim,
-    _check_same_t
+    check_exact_dim,
+    check_same_dim,
+    check_same_dt,
+    check_same_t,
+    check_uniform_time_spaced,
 )
+from yupi.trajectory import Trajectory
+from yupi.transformations import subsample
+from yupi.vector import Vector
 
 
-def collect_at_step(trajs: List[Trajectory], step: int, warnings: bool = True,
-                    velocity: bool = False,
-                    func: Callable[[Vector], Vector] = None) -> np.ndarray:
+def collect_at_step(
+    trajs: List[Trajectory],
+    step: int,
+    warnings: bool = True,
+    velocity: bool = False,
+    func: Optional[Callable[[Vector], Vector]] = None,
+) -> np.ndarray:
     """
     Collects the positional data (or velocity) of each trajectory at a given
     step.
@@ -31,7 +43,7 @@ def collect_at_step(trajs: List[Trajectory], step: int, warnings: bool = True,
         True.
     velocity : bool
         If True, the velocity of the trajectory is used, by default False.
-    func : Callable[[Vector], Vector]
+    func : Optional[Callable[[Vector], Vector]]
         Function to apply to the collected vector of each trajectory.
         By default, the identity function.
 
@@ -44,12 +56,16 @@ def collect_at_step(trajs: List[Trajectory], step: int, warnings: bool = True,
     --------
     collect_at_time, collect_step_lagged, collect_time_lagged, collect
     """
-    return collect(trajs, at=int(step), warnings=warnings, velocity=velocity,
-                   func=func)
+    return collect(trajs, at=int(step), warnings=warnings, velocity=velocity, func=func)
 
-def collect_at_time(trajs: List[Trajectory], time: float, warnings: bool = True,
-                    velocity: bool = False,
-                    func: Callable[[Vector], Vector] = None) -> np.ndarray:
+
+def collect_at_time(
+    trajs: List[Trajectory],
+    time: float,
+    warnings: bool = True,
+    velocity: bool = False,
+    func: Optional[Callable[[Vector], Vector]] = None,
+) -> np.ndarray:
     """
     Collects the positional data (or velocity) of each trajectory at a given
     time.
@@ -67,7 +83,7 @@ def collect_at_time(trajs: List[Trajectory], time: float, warnings: bool = True,
         True.
     velocity : bool
         If True, the velocity of the trajectory is used, by default False.
-    func : Callable[[Vector], Vector]
+    func : Optional[Callable[[Vector], Vector]]
         Function to apply to the collected vector of each trajectory.
         By default, the identity function.
 
@@ -80,12 +96,19 @@ def collect_at_time(trajs: List[Trajectory], time: float, warnings: bool = True,
     --------
     collect_at_step, collect_step_lagged, collect_time_lagged, collect
     """
-    return collect(trajs, at=float(time), warnings=warnings, velocity=velocity,
-                   func=func)
+    return collect(
+        trajs, at=float(time), warnings=warnings, velocity=velocity, func=func
+    )
 
-def collect_step_lagged(trajs: List[Trajectory], step: int, warnings: bool = True,
-                        velocity: bool = False, concat: bool = True,
-                        func: Callable[[Vector], Vector] = None) -> np.ndarray:
+
+def collect_step_lagged(
+    trajs: List[Trajectory],
+    step: int,
+    warnings: bool = True,
+    velocity: bool = False,
+    concat: bool = True,
+    func: Optional[Callable[[Vector], Vector]] = None,
+) -> np.ndarray:
     """
     Collects the positional data (or velocity) of each trajectory lagged by a
     given step.
@@ -103,7 +126,7 @@ def collect_step_lagged(trajs: List[Trajectory], step: int, warnings: bool = Tru
         If True, the velocity of the trajectory is used, by default False.
     concat : bool
         If True, the data is concatenated, by default True.
-    func : Callable[[Vector], Vector]
+    func : Optional[Callable[[Vector], Vector]]
         Function to apply to the collected vector of each trajectory.
         By default, the identity function.
 
@@ -116,12 +139,24 @@ def collect_step_lagged(trajs: List[Trajectory], step: int, warnings: bool = Tru
     --------
     collect_at_step, collect_at_step, collect_time_lagged, collect
     """
-    return collect(trajs, lag=int(step), concat=concat, warnings=warnings,
-                   velocity=velocity, func=func)
+    return collect(
+        trajs,
+        lag=int(step),
+        concat=concat,
+        warnings=warnings,
+        velocity=velocity,
+        func=func,
+    )
 
-def collect_time_lagged(trajs: List[Trajectory], time: float, warnings: bool = True,
-                        velocity: bool = False, concat: bool = True,
-                        func: Callable[[Vector], Vector] = None) -> np.ndarray:
+
+def collect_time_lagged(
+    trajs: List[Trajectory],
+    time: float,
+    warnings: bool = True,
+    velocity: bool = False,
+    concat: bool = True,
+    func: Optional[Callable[[Vector], Vector]] = None,
+) -> np.ndarray:
     """
     Collects the positional data (or velocity) of each trajectory lagged by a
     given time.
@@ -139,7 +174,7 @@ def collect_time_lagged(trajs: List[Trajectory], time: float, warnings: bool = T
         If True, the velocity of the trajectory is used, by default False.
     concat : bool
         If True, the data is concatenated, by default True.
-    func : Callable[[Vector], Vector]
+    func : Optional[Callable[[Vector], Vector]]
         Function to apply to the collected vector of each trajectory.
         By default, the identity function.
 
@@ -152,14 +187,25 @@ def collect_time_lagged(trajs: List[Trajectory], time: float, warnings: bool = T
     --------
     collect_at_step, collect_at_time, collect_step_lagged, collect
     """
-    return collect(trajs, lag=float(time), concat=concat, warnings=warnings,
-                   velocity=velocity, func=func)
+    return collect(
+        trajs,
+        lag=float(time),
+        concat=concat,
+        warnings=warnings,
+        velocity=velocity,
+        func=func,
+    )
 
 
-def collect(trajs: List[Trajectory], lag: Union[int, float] = None,
-            concat: bool = True, warnings: bool = True, velocity: bool = False,
-            func: Callable[[Vector], Any] = None,
-            at: Union[int, float] = None) -> np.ndarray:
+def collect(
+    trajs: List[Trajectory],
+    lag: Optional[Union[int, float]] = None,
+    concat: bool = True,
+    warnings: bool = True,
+    velocity: bool = False,
+    func: Optional[Callable[[Vector], Vector]] = None,
+    at: Optional[Union[int, float]] = None,  # pylint: disable=invalid-name
+) -> np.ndarray:
     """
     Collect general function.
 
@@ -173,7 +219,7 @@ def collect(trajs: List[Trajectory], lag: Union[int, float] = None,
     ----------
     trajs : List[Trajectory]
         Group of trajectories.
-    lag : int or float, optional
+    lag : Optional[Union[int, float]]
         If int, the number of samples to lag. If float, the time to lag.
     concat : bool, optional
         If true each trajectory stracted data will be concatenated in
@@ -184,9 +230,9 @@ def collect(trajs: List[Trajectory], lag: Union[int, float] = None,
     velocity : bool, optional
         If true, the velocity will be returned (calculated using the
         lag if given), by default False.
-    func : Callable[[Vector], Any], optional
+    func : Optional[Callable[[Vector], Vector]]
         Function to apply to each resulting vector, by default None.
-    at : Union[int, float], optional
+    at : Optional[Union[int, float]]
         If int, the index of the collected vector in the trajectory. If
         float, it is taken as time and the index is calculated using
         the trajectory's dt.
@@ -202,28 +248,30 @@ def collect(trajs: List[Trajectory], lag: Union[int, float] = None,
         If ``lag`` and ``at`` are given at the same time.
     """
 
-    is_step = lag is not None and isinstance(lag, int)
-    is_time = lag is not None and isinstance(lag, float)
-    is_at_step = at is not None and isinstance(at, int)
-    is_at_time = at is not None and isinstance(at, float)
+    checks = [
+        isinstance(lag, int),
+        isinstance(lag, float),
+        isinstance(at, int),
+        isinstance(at, float),
+    ]
 
-    if is_step + is_time + is_at_step + is_at_time == 0:
-        is_step = True
+    if sum(checks) == 0:
         lag = 0
-    if is_step + is_time + is_at_step + is_at_time > 1:
-        raise ValueError("You can not set `lag` and `at` parameters at the "
-                         "same time")
-    is_lag = is_step or is_time
-    is_at = is_at_step or is_at_time
-
+        checks[0] = True
+    if sum(checks) > 1:
+        raise ValueError(
+            "You can not set `lag` and `at` parameters at the " "same time"
+        )
+    is_lag = checks[0] or checks[1]
 
     data = []
-
     for traj in trajs:
         if is_lag:
-            step = int(lag / traj.dt) if is_time else int(lag)
+            assert lag is not None
+            step = int(lag / traj.dt) if checks[1] else int(lag)
         else:
-            step = int(at / traj.dt) if is_at_time else int(at)
+            assert at is not None
+            step = int(at / traj.dt) if checks[3] else int(at)
 
         current_vec = traj.r
         if step == 0:
@@ -235,11 +283,12 @@ def collect(trajs: List[Trajectory], lag: Union[int, float] = None,
             continue
 
         if warnings and step >= len(current_vec):
-            logging.warning(f"Trajectory {traj.traj_id} is shorten than "
-                            f"{step} samples")
+            logging.warning(
+                "Trajectory %s is shorten than %i samples", traj.traj_id, step
+            )
             continue
 
-        if is_at:
+        if not is_lag:  # Is at
             data.append(current_vec[step])
             continue
 
@@ -254,16 +303,16 @@ def collect(trajs: List[Trajectory], lag: Union[int, float] = None,
 
     if concat and is_lag:
         return np.concatenate(data)
-    equal_len = np.all(len(d) == len(data[0]) for d in data)
+    equal_len = np.all([len(d) == len(data[0]) for d in data])
     return np.array(data) if equal_len else np.array(data, dtype=object)
 
 
-@_check_same_dt
-@_check_exact_dim(2)
-@_check_uniform_time_spaced
-def turning_angles_ensemble(trajs: List[Trajectory], accumulate=False,
-                            degrees=False, centered=False,
-                            wrap=True) -> np.ndarray:
+@check_same_dt
+@check_exact_dim(2)
+@check_uniform_time_spaced
+def turning_angles_ensemble(
+    trajs: List[Trajectory], accumulate=False, degrees=False, centered=False, wrap=True
+) -> np.ndarray:
     """
     Return a concatenation of all the turning angles that forms
     a set of trajectories.
@@ -297,7 +346,7 @@ def turning_angles_ensemble(trajs: List[Trajectory], accumulate=False,
     return np.concatenate(theta)
 
 
-@_check_same_dim
+@check_same_dim
 def speed_ensemble(trajs: List[Trajectory], step: int = 1) -> np.ndarray:
     """
     Estimate speeds of the list of trajectories, ``trajs``,
@@ -321,7 +370,7 @@ def speed_ensemble(trajs: List[Trajectory], step: int = 1) -> np.ndarray:
     return np.concatenate([traj.v.norm for traj in trajs_])
 
 
-@_check_same_t
+@check_same_t
 def msd_ensemble(trajs: List[Trajectory]) -> np.ndarray:
     """
     Compute the square displacements for every Trajectory object
@@ -349,17 +398,16 @@ def msd_ensemble(trajs: List[Trajectory]) -> np.ndarray:
         r = traj.r
 
         # Square displacements
-        r_2 = (r - r[0])**2            # Square coordinates
-        r2 = np.sum(r_2, axis=1)       # Square distances
-        _msd.append(r2)                 # Append square distances
+        r_2 = (r - r[0]) ** 2  # Square coordinates
+        r_2_dis = np.sum(r_2, axis=1)  # Square distances
+        _msd.append(r_2_dis)  # Append square distances
 
     # Transpose to have time/trials as first/second axis
-    _msd = np.transpose(_msd)
-    return _msd
+    return np.transpose(_msd)
 
 
-@_check_same_dt
-@_check_uniform_time_spaced
+@check_same_dt
+@check_uniform_time_spaced
 def msd_time(trajs: List[Trajectory], lag: int) -> np.ndarray:
     """
     Estimate the mean square displacement for every Trajectory
@@ -393,9 +441,9 @@ def msd_time(trajs: List[Trajectory], lag: int) -> np.ndarray:
         current_msd = np.empty(lag)
         for lag_ in range(1, lag + 1):
             # Lag displacement vectors
-            dr = r[lag_:] - r[:-lag_]
+            lagged_r = r[lag_:] - r[:-lag_]
             # Lag displacement
-            dr2 = np.sum(dr**2, axis=1)
+            dr2 = np.sum(lagged_r**2, axis=1)
             # Averaging over a single realization
             current_msd[lag_ - 1] = np.mean(dr2)
 
@@ -403,13 +451,13 @@ def msd_time(trajs: List[Trajectory], lag: int) -> np.ndarray:
         _msd.append(current_msd)
 
     # Transpose to have time/trials as first/second axis
-    _msd = np.transpose(_msd)
-    return _msd
+    return np.transpose(_msd)
 
 
-@_check_same_dim
-def msd(trajs: List[Trajectory], time_avg: bool = True,
-        lag: int = None) -> Tuple[np.ndarray, np.ndarray]:
+@check_same_dim
+def msd(
+    trajs: List[Trajectory], time_avg: bool = True, lag: Optional[int] = None
+) -> Tuple[np.ndarray, np.ndarray]:
     """
     Estimate the mean square displacement of the list of Trajectory
     objects, ``trajs``, providing the options of averaging over the
@@ -424,7 +472,7 @@ def msd(trajs: List[Trajectory], time_avg: bool = True,
         time. Otherwise, an ensemble average will be performed and all
         Trajectory objects will have to have the same length. By default
         True.
-    lag : None, optional
+    lag : Optional[int]
         If None, ``time_avg`` should be set to ``False`` indicating
         ensemble average. Otherwise, ``lag`` is taken as the number
         of steps that multiplied by ``dt`` defines the lag time. By
@@ -438,18 +486,18 @@ def msd(trajs: List[Trajectory], time_avg: bool = True,
     """
 
     if not time_avg:
-        _msd = msd_ensemble(trajs)   # Ensemble average
+        _msd = msd_ensemble(trajs)  # Ensemble average
     elif lag is None:
         raise ValueError("You must set 'lag' param if 'time_avg' is True")
     else:
         _msd = msd_time(trajs, lag)  # Time average
 
     msd_mean = np.mean(_msd, axis=1)  # Mean
-    msd_std = np.std(_msd, axis=1)    # Standard deviation
+    msd_std = np.std(_msd, axis=1)  # Standard deviation
     return msd_mean, msd_std
 
 
-@_check_same_t
+@check_same_t
 def vacf_ensemble(trajs: List[Trajectory]) -> np.ndarray:
     """
     Compute the pair-wise dot product between initial and current
@@ -480,12 +528,11 @@ def vacf_ensemble(trajs: List[Trajectory]) -> np.ndarray:
         _vacf.append(v0_dot_v)
 
     # Transpose to have time/trials as first/second axis
-    _vacf = np.transpose(_vacf)
-    return _vacf
+    return np.transpose(_vacf)
 
 
-@_check_same_dt
-@_check_uniform_time_spaced
+@check_same_dt
+@check_uniform_time_spaced
 def vacf_time(trajs: List[Trajectory], lag: int) -> np.ndarray:
     """
     Estimate the velocity autocorrelation function for every
@@ -532,13 +579,13 @@ def vacf_time(trajs: List[Trajectory], lag: int) -> np.ndarray:
         _vacf.append(current_vacf)
 
     # Aranspose to have time/trials as first/second axis
-    _vacf = np.transpose(_vacf)
-    return _vacf
+    return np.transpose(_vacf)
 
 
-@_check_same_dim
-def vacf(trajs: List[Trajectory], time_avg: bool = True,
-        lag: int = None) -> Tuple[np.ndarray, np.ndarray]:
+@check_same_dim
+def vacf(
+    trajs: List[Trajectory], time_avg: bool = True, lag: Optional[int] = None
+) -> Tuple[np.ndarray, np.ndarray]:
     """
     Estimate the velocity autocorrelation function of the list of
     Trajectory objects, ``trajs``, providing the options of averaging
@@ -553,7 +600,7 @@ def vacf(trajs: List[Trajectory], time_avg: bool = True,
         averaging over time. Otherwise, an ensemble average will be
         performed and all Trajectory objects will have to have the
         same length. By default True.
-    lag : int, optional
+    lag : Optional[int]
         If None, ``time_avg`` should be set to ``False`` indicating
         ensemble average. Otherwise, ``lag`` is taken as the number
         of steps that multiplied by ``dt`` defines the lag time.
@@ -567,14 +614,14 @@ def vacf(trajs: List[Trajectory], time_avg: bool = True,
     """
 
     if not time_avg:
-        _vacf = vacf_ensemble(trajs)   # Ensemble average
+        _vacf = vacf_ensemble(trajs)  # Ensemble average
     elif lag is None:
         raise ValueError("You must set 'lag' param if 'time_avg' is True")
     else:
         _vacf = vacf_time(trajs, lag)  # Time average
 
     vacf_mean = np.mean(_vacf, axis=1)  # Mean
-    vacf_std = np.std(_vacf, axis=1)    # Standard deviation
+    vacf_std = np.std(_vacf, axis=1)  # Standard deviation
     return vacf_mean, vacf_std
 
 
@@ -605,14 +652,14 @@ def _kurtosis(arr):
 
         # Second and fourth central moments averaging
         # over repetitions
-        m2 = np.mean(arr_zm**2)
-        m4 = np.mean(arr_zm**4)
+        m_2 = np.mean(arr_zm**2)
+        m_4 = np.mean(arr_zm**4)
 
         # Compute kurtosis for those cases in which the
         # second moment is different from zero
-        if m2 == 0:
+        if m_2 == 0:
             return 0
-        kurt = m4 / m2**2
+        kurt = m_4 / m_2**2
         return kurt
 
     # MULTIDIMENSIONAL CASE
@@ -620,7 +667,7 @@ def _kurtosis(arr):
     # (i.e., a horizontal sequence of column vectors)
 
     # Subtract the mean position
-    arr_zm = arr - arr.mean(1)[:,None]
+    arr_zm = arr - arr.mean(1)[:, None]
 
     try:
         # Inverse of the estimated covariance matrix
@@ -630,12 +677,13 @@ def _kurtosis(arr):
         return 0
 
     # Kurtosis definition for multivariate r.v.'s
-    k = np.sum(arr_zm * (cov_inv @ arr_zm), axis=0)
-    kurt = np.mean(k**2)
+    _k = np.sum(arr_zm * (cov_inv @ arr_zm), axis=0)
+    kurt = np.mean(_k**2)
 
     return kurt
 
-@_check_same_t
+
+@check_same_t
 def kurtosis_ensemble(trajs: List[Trajectory]) -> np.ndarray:
     """Estimate kurtosis as a function of time of the
     list of Trajectory objects, ``trajs``. The average
@@ -654,19 +702,19 @@ def kurtosis_ensemble(trajs: List[Trajectory]) -> np.ndarray:
 
     # Get ensemble positions where axis 0/1/2 are
     # in the order trials/time/dim
-    r = [traj.r for traj in trajs]
+    r = Vector([traj.r for traj in trajs])
 
     # Set trials as the last axis
-    r = np.moveaxis(r, 0, 2)
+    moved_r = np.moveaxis(r, 0, 2)
 
     # Compute kurtosis at every time instant (loop over time)
-    kurt = [_kurtosis(r_) for r_ in r]
+    kurt = [_kurtosis(r_) for r_ in moved_r]
 
     return np.array(kurt)
 
 
-@_check_same_dt
-@_check_uniform_time_spaced
+@check_same_dt
+@check_uniform_time_spaced
 def kurtosis_time(trajs: List[Trajectory], lag: int) -> np.ndarray:
     """
     Estimate the kurtosis for every Trajectory object stored
@@ -692,19 +740,19 @@ def kurtosis_time(trajs: List[Trajectory], lag: int) -> np.ndarray:
         current_kurt = np.empty(lag)
         for lag_ in range(lag):
             try:
-                dr = traj.r[lag_:] - traj.r[:-lag_]
+                lagged_r = traj.r[lag_:] - traj.r[:-lag_]
             except ValueError:
                 current_kurt[lag_] = 0
                 continue
-            current_kurt[lag_] = _kurtosis(dr.T)
+            current_kurt[lag_] = _kurtosis(lagged_r.T)
         kurt.append(current_kurt)
-    kurt = np.transpose(kurt)
-    return kurt
+    return np.transpose(kurt)
 
 
-@_check_same_dim
-def kurtosis(trajs: List[Trajectory], time_avg: bool = True,
-             lag: int = None) -> Tuple[np.ndarray, np.ndarray]:
+@check_same_dim
+def kurtosis(
+    trajs: List[Trajectory], time_avg: bool = True, lag: Optional[int] = None
+) -> Tuple[np.ndarray, Optional[np.ndarray]]:
     """
     Estimate the kurtosis of the list of Trajectory objects, ``trajs``,
     providing the options of averaging over the ensemble of realizations
@@ -718,7 +766,7 @@ def kurtosis(trajs: List[Trajectory], time_avg: bool = True,
         If True, kurtosis is estimated averaging over time. Otherwise,
         an ensemble average will be performed and all Trajectory objects
         will have to have the same length. By default True.
-    lag : int, optional
+    lag : Optional[int]
         If None, ``time_avg`` should be set to ``False`` indicating
         ensemble average. Otherwise, ``lag`` is taken as the number
         of steps that multiplied by ``dt`` defines the lag time.
@@ -726,13 +774,13 @@ def kurtosis(trajs: List[Trajectory], time_avg: bool = True,
 
     Returns
     -------
-    Tuple[np.ndarray, np.ndarray]
+    Tuple[np.ndarray, Optional[np.ndarray]]
         Tuple containgin the kurtosis and the standar deviations.
     """
 
     if not time_avg:
         return kurtosis_ensemble(trajs), None
-    elif lag is None:
+    if lag is None:
         raise ValueError("You must set 'lag' param if 'time_avg' is True")
 
     kurt = kurtosis_time(trajs, lag)
@@ -741,7 +789,7 @@ def kurtosis(trajs: List[Trajectory], time_avg: bool = True,
     return kurt_mean, kurt_std
 
 
-@_check_same_dim
+@check_same_dim
 def kurtosis_reference(trajs: List[Trajectory]) -> float:
     """Get the sampled kurtosis for the case of
     ``len(trajs)`` trajectories whose position
@@ -758,17 +806,19 @@ def kurtosis_reference(trajs: List[Trajectory]) -> float:
         Value of kurtosis.
     """
 
-    d = trajs[0].dim
-    n = len(trajs)
-    kurt = d * (d + 2)
-    if n == 1:
+    dim = trajs[0].dim
+    count = len(trajs)
+    kurt = dim * (dim + 2)
+    if count == 1:
         return kurt
-    return kurt * (n - 1) / (n + 1)
+    return kurt * (count - 1) / (count + 1)
 
 
-@_check_same_dt
-@_check_uniform_time_spaced
-def psd(trajs: List[Trajectory], lag: int, omega: bool = True) -> np.ndarray:
+@check_same_dt
+@check_uniform_time_spaced
+def psd(
+    trajs: List[Trajectory], lag: int, omega: bool = True
+) -> Tuple[np.ndarray, np.ndarray, np.ndarray]:
     """
     Estimate the power spectral density of a list of Trajectory object
     as the Fourier transform of its velocity autocorrelation function.
@@ -791,13 +841,13 @@ def psd(trajs: List[Trajectory], lag: int, omega: bool = True) -> np.ndarray:
     """
 
     _vacf = vacf_time(trajs, lag)
-    ft = np.fft.fft(_vacf, axis=0) * trajs[0].dt
-    ft = np.fft.fftshift(ft)
-    ft_abs = np.abs(ft)
+    _ft = np.fft.fft(_vacf, axis=0) * trajs[0].dt
+    _ft = np.fft.fftshift(_ft)
+    ft_abs = np.abs(_ft)
     ft_mean = np.mean(ft_abs, axis=1)
     ft_std = np.std(ft_abs, axis=1)
 
-    frec = 2*np.pi * np.fft.fftfreq(lag, trajs[0].dt)
+    frec = 2 * np.pi * np.fft.fftfreq(lag, trajs[0].dt)
     frec = np.fft.fftshift(frec)
 
     return ft_mean, ft_std, frec * 2 * np.pi if omega else frec
