@@ -1,20 +1,42 @@
+"""
+Contains the basic structures for trajectories.
+"""
+
 from __future__ import annotations
 
 import csv
 import json
 import logging
 import os
+import warnings
 from pathlib import Path
-from typing import List, NamedTuple, Tuple, Union
+from typing import (
+    Any,
+    Collection,
+    Dict,
+    Iterator,
+    List,
+    NamedTuple,
+    Optional,
+    Tuple,
+    Union,
+    cast,
+)
 
 import numpy as np
 
-import yupi._vel_estimators as vel_estimators
+import yupi._differentiation as diff
 from yupi.exceptions import LoadTrajectoryError
 from yupi.features import Features
 from yupi.vector import Vector
 
-_threshold = 1e-12
+_THRESHOLD = 1e-12
+
+Axis = Collection[float]
+"""Represents the data for a single axis."""
+
+Point = Collection[float]
+"""Represents a single point."""
 
 
 class TrajectoryPoint(NamedTuple):
@@ -25,8 +47,6 @@ class TrajectoryPoint(NamedTuple):
     ----------
     r : Vector
         Positional data.
-    ang : Vector
-        Angular data.
     v : Vector
         Velocity data.
     t : float
@@ -34,7 +54,6 @@ class TrajectoryPoint(NamedTuple):
     """
 
     r: Vector
-    ang: Vector
     v: Vector
     t: float
 
@@ -47,44 +66,51 @@ class Trajectory:
 
     Parameters
     ----------
-    x : np.ndarray
+    x : Optional[Axis]
         Array containing position data of X axis, by default None
-    y : np.ndarray
+    y : Optional[Axis]
         Array containing position data of Y axis, by default None.
-    z : np.ndarray
+    z : Optional[Axis]
         Array containing position data of X axis, by default None.
-    points : np.ndarray
+    points : Optional[Collection[Point]]
         Array containing position data as a list of points, by default
         None
-    axes : np.ndarray
+    axes : Optional[Collection[Axis]]
         Array containing position data as a list of axis, by default
         None
-    t : np.ndarray
+    t : Optional[Collection[float]]
         Array containing time data, by default None.
-    ang : np.ndarray
-        Array containing angle data, by default None.
     dt : float
         If no time data is given this represents the time between each
         position data value.
-    t0 : float
+    t_0 : float
         If no time data is given this represents the initial time value,
         by default 0.
     traj_id : str
         Id of the trajectory.
     lazy : bool
         Defines if the velocity vector is not recalculated every time
-        is asked.
-    vel_est : dict
-        Dictionary containing the parameters for the velocity estimation
-        method.
+        is asked. By default False.
+    diff_est : Dict[str, Any]
+        Dictionary containing the parameters for the differentiation
+        estimation method used to calculate velocity.
 
     Attributes
     ----------
-    dt : float
-        If no time data is given this represents the time between each
-        position data value.
-    id : str
+    r : Vector
+        Position vector.
+    dt_mean : float
+        Mean of the time data delta.
+    dt_std : float
+        Standard deviation of the time between each position data value.
+    traj_id : str
         Id of the trajectory.
+    lazy : bool
+        Defines if the velocity vector is not recalculated every time
+        is asked.
+    diff_est : dict
+        Dictionary containing the parameters for the differentiation
+        estimation method used to calculate velocity.
 
     Examples
     --------
@@ -115,8 +141,8 @@ class Trajectory:
     ValueError
         If no positional data is given.
     ValueError
-        If all the given input data (``x``, ``y``, ``z``, ``t``,
-        ``ang``) does not have the same shape.
+        If all the given input data (``x``, ``y``, ``z``, ``t``)
+        does not have the same length.
     ValueError
         If ``t`` and ``dt`` given but ``t`` is not uniformly spaced.
     ValueError
@@ -124,26 +150,27 @@ class Trajectory:
         values delta.
     """
 
-    __vel_est = {
-        "method": vel_estimators.VelocityMethod.LINEAR_DIFF,
-        "window_type": vel_estimators.WindowType.CENTRAL,
+    general_diff_est: Dict[str, Any] = {
+        "method": diff.DiffMethod.LINEAR_DIFF,
+        "window_type": diff.WindowType.CENTRAL,
     }
 
     def __init__(
         self,
-        x: np.ndarray = None,
-        y: np.ndarray = None,
-        z: np.ndarray = None,
-        points: np.ndarray = None,
-        axes: np.ndarray = None,
-        t: np.ndarray = None,
-        ang: np.ndarray = None,
-        dt: float = None,
-        t0: float = 0.0,
-        traj_id: str = None,
-        lazy: bool = False,
-        vel_est: dict = None,
-    ):
+        x: Optional[Axis] = None,
+        y: Optional[Axis] = None,
+        z: Optional[Axis] = None,
+        points: Optional[Collection[Point]] = None,
+        axes: Optional[Collection[Axis]] = None,
+        t: Optional[Collection[float]] = None,
+        dt: Optional[float] = None,
+        t_0: float = 0.0,
+        traj_id: Optional[str] = None,
+        lazy: Optional[bool] = False,
+        diff_est: Optional[Dict[str, Any]] = None,
+        vel_est: Optional[Dict[str, Any]] = None,
+        t0: Optional[float] = None,  # pylint: disable=invalid-name
+    ):  # pylint: disable=too-many-arguments
 
         # Position data validation
         from_xyz = x is not None
@@ -157,40 +184,40 @@ class Trajectory:
             )
 
         # Set position data
-        self.r = None
-        data: List[Vector] = [t, ang]
-        lengths = [len(item) for item in data if item is not None]
-
-        for i, item in enumerate(data):
-            if item is not None:
-                data[i] = Vector.create(item, dtype=float)
+        lengths = [len(t)] if t is not None else []
 
+        # xyz data is converted to axes
         if from_xyz:
             axes = [d for d in [x, y, z] if d is not None]
-            from_axes = True
 
-        if from_axes and len(axes) > 0:
+        # Check if positional data is given
+        if axes is not None and len(axes) > 0:
             lengths.extend([len(d) for d in axes])
-            self.r = Vector.create(axes, dtype=float).T
-
-        if from_points:
+            self.r = Vector(axes, dtype=float, copy=True).T
+        elif points is not None:
             lengths.append(len(points))
-            self.r = Vector.create(points, dtype=float)
-
-        if self.r is None:
+            self.r = Vector(points, dtype=float, copy=True)
+        else:
             raise ValueError("No position data were given.")
 
+        # Check if all the given data has the same shape
         if lengths.count(lengths[0]) != len(lengths):
-            raise ValueError("All input arrays must have the same shape.")
-
+            raise ValueError("All input arrays must have the same lenght.")
         if len(self.r) < 2:
             raise ValueError("The trajectory must contain at least 2 points.")
 
+        if t0 is not None:
+            t_0 = t0
+            warnings.warn(
+                "'t0' is deprecated and will be removed in a future version, "
+                "use 't_0' instead.",
+                DeprecationWarning,
+            )
+
         self.__dt = dt
-        self.dt_mean = dt
-        self.__t0 = t0
-        self.__t = data[0]
-        self.ang = data[1]
+        self.t_0 = t_0
+        self.__t = None if t is None else Vector(t, dtype=float, copy=True)
+        self.__v: Optional[Vector] = None
         self.traj_id = traj_id
         self.lazy = lazy
 
@@ -202,85 +229,126 @@ class Trajectory:
             self.dt_mean = np.mean(np.array(self.__t.delta))
             self.dt_std = np.std(np.array(self.__t.delta))
 
-        # Velocity estimation
-        self.vel_est = Trajectory.__vel_est.copy()
+        # Differentiation method
         if vel_est is not None:
-            self.vel_est.update(vel_est)
-
-        self.recalculate_velocity()
+            diff_est = vel_est
+            warnings.warn(
+                "'vel_est' is deprecated and will be removed in a future version, "
+                "use 'diff_est' instead.",
+                DeprecationWarning,
+            )
+        self.diff_est = Trajectory.general_diff_est.copy()
+        if diff_est is not None:
+            self.diff_est.update(diff_est)
 
         # Time parameters validation
-        if t is not None and dt is not None:
-            if abs(self.dt_mean - dt) > _threshold:
+        if self.__t is not None and dt is not None:
+            if abs(self.dt_mean - dt) > _THRESHOLD:
                 raise ValueError(
                     "You are giving 'dt' and 't' but 'dt' "
                     "does not match with time values delta."
                 )
-            if abs(self.dt_std - 0) > _threshold:
+            if abs(self.dt_std - 0) > _THRESHOLD:
                 raise ValueError(
-                    "You are giving 'dt' and 't' but 't' is " "not uniformly spaced."
+                    "You are giving 'dt' and 't' but 't' is not uniformly spaced."
                 )
-            if abs(self.__t[0] - t0) > _threshold:
+            if abs(self.__t[0] - t_0) > _THRESHOLD:
                 raise ValueError(
-                    "You are giving 'dt' and 't' but 't0' is not "
+                    "You are giving 'dt' and 't' but 't_0' is not "
                     "the same as the first value of 't'."
                 )
 
         self.features = Features(self)
 
-    def set_vel_method(
+    def set_diff_method(
         self,
-        method: vel_estimators.VelocityMethod,
-        window_type: vel_estimators.WindowType = vel_estimators.WindowType.CENTRAL,
+        method: diff.DiffMethod,
+        window_type: diff.WindowType = diff.WindowType.CENTRAL,
         accuracy: int = 1,
     ):
         """
-        Set the method to calculate the velocity.
+        Set the local diferentiation method.
 
         Parameters
         ----------
-        method : VelocityMethod
-            Method to calculate the velocity.
+        method : DiffMethod
+            Method used to differentiate.
         window_type : WindowType
-            Type of window to use to calculate the velocity. By default,
+            Type of window used in the differentiation method. By default,
             the central window is used.
         accuracy : int
-            Accuracy of the velocity estimation (only valid for
+            Accuracy of the differentiation method (only valid for
             FORNBERG_DIFF method). By default, the accuracy is 1.
         """
-        self.vel_est = {
+        self.diff_est = {
             "method": method,
             "window_type": window_type,
             "accuracy": accuracy,
         }
         self.recalculate_velocity()
 
-    @staticmethod
-    def global_vel_method(
-        method: vel_estimators.VelocityMethod,
-        window_type: vel_estimators.WindowType = vel_estimators.WindowType.CENTRAL,
+    def set_vel_method(
+        self,
+        method: diff.DiffMethod,
+        window_type: diff.WindowType = diff.WindowType.CENTRAL,
         accuracy: int = 1,
     ):
         """
-        Set the method to calculate the velocity.
+        .. deprecated:: 0.10.0
+            :func:`set_vel_method` is deprecated and will be removed in
+            version 1.0.0, use :func:`set_diff_method` instead.
+        """
+        warnings.warn(
+            "'set_vel_method' is deprecated and will be removed in a future version, "
+            "use 'set_diff_method' instead.",
+            DeprecationWarning,
+        )
+        self.set_diff_method(method, window_type, accuracy)
+
+    @staticmethod
+    def global_diff_method(
+        method: diff.DiffMethod,
+        window_type: diff.WindowType = diff.WindowType.CENTRAL,
+        accuracy: int = 1,
+    ):
+        """
+        Set the global diferentiation method.
 
         Parameters
         ----------
-        method : VelocityMethod
-            Method to calculate the velocity.
+        method : DiffMethod
+            Method used to differentiate.
         window_type : WindowType
-            Type of window to use to calculate the velocity. By default,
+            Type of window used in the differentiation method. By default,
             the central window is used.
         accuracy : int
-            Accuracy of the velocity estimation (only valid for
-            FORNBERG method). By default, the accuracy is 1.
+            Accuracy of the differentiation method (only valid for
+            FORNBERG_DIFF method). By default, the accuracy is 1.
         """
-        Trajectory.__vel_est = {
+        Trajectory.general_diff_est = {
             "method": method,
             "window_type": window_type,
             "accuracy": accuracy,
         }
 
+    @staticmethod
+    def global_vel_method(
+        method: diff.DiffMethod,
+        window_type: diff.WindowType = diff.WindowType.CENTRAL,
+        accuracy: int = 1,
+    ):
+        """
+        .. deprecated:: 0.10.0
+            :func:`global_vel_method` is deprecated and will be removed in
+            version 1.0.0, use :func:`global_diff_method` instead.
+        """
+        warnings.warn(
+            "'global_vel_method' is deprecated and will be removed in "
+            "version 1.0.0, use 'global_diff_method' instead.",
+            DeprecationWarning,
+        )
+        Trajectory.global_diff_method(method, window_type, accuracy)
+
     @property
     def dt(self) -> float:
         """
@@ -297,69 +365,52 @@ class Trajectory:
         if self.__t is not None:
             starts_at_zero = self.__t[0] == 0
             std_is_zero = self.dt_std == 0
-            if starts_at_zero and std_is_zero:
-                return True
-            return False
+            return starts_at_zero and std_is_zero
         return True
 
-    def __len__(self):
+    def __len__(self) -> int:
         return self.r.shape[0]
 
-    def __getitem__(self, index):
+    def __getitem__(self, index) -> Union[Trajectory, TrajectoryPoint]:
         if isinstance(index, int):
-            # *dim, *ang, v, t
-            data = [self.r[index], [], None, None]
+            # r, v, t
+            data = [self.r[index], None, None]
+            data[1] = self.v[index - 1] if index > 0 else Vector([0] * self.dim)
+            data[2] = (
+                self.t[index] if self.__t is not None else self.t_0 + index * self.dt
+            )
 
-            # Angle
-            if self.ang is not None:
-                data[1] = self.ang[index]
-
-            # Velocity
-            data[2] = self.v[index - 1] if index > 0 else Vector.create([0] * self.dim)
-
-            # Time
-            if self.__t is not None:
-                data[3] = self.__t[index]
-            else:
-                data[3] = self.__t0 + self.dt * index
-
-            r, ang, v, t = data
-            return TrajectoryPoint(r=r, ang=ang, v=v, t=t)
+            r, v, t = data
+            return TrajectoryPoint(r=r, v=v, t=t)
 
         if isinstance(index, slice):
             start, stop, step = index.indices(len(self))
-
             new_points = self.r[start:stop:step]
-            new_ang = None
-            if self.ang is not None:
-                new_ang = self.ang[start:stop:step]
             if self.uniformly_spaced:
                 new_dt = self.dt * step
-                new_t0 = self.__t0 + start * self.dt
+                new_t0 = self.t_0 + start * self.dt
                 return Trajectory(
                     points=new_points,
-                    ang=new_ang,
                     dt=new_dt,
-                    t0=new_t0,
-                    vel_est=self.vel_est,
+                    t_0=new_t0,
+                    diff_est=self.diff_est,
                 )
             new_t = self.t[start:stop:step]
-            return Trajectory(
-                points=new_points, ang=new_ang, t=new_t, vel_est=self.vel_est
-            )
+            return Trajectory(points=new_points, t=new_t, diff_est=self.diff_est)
+        raise TypeError("Index must be an integer or a slice.")
 
-    def __iter__(self):
+    def __iter__(self) -> Iterator[TrajectoryPoint]:
         for i in range(len(self)):
-            yield self[i]
+            yield cast(TrajectoryPoint, self[i])
 
     @property
-    def bounds(self) -> List[Tuple[float]]:
+    def bounds(self) -> List[Tuple[float, float]]:
         """List[Tuple[float]] : List of tuples indicanting the min and
         max values of each dimension"""
         _bounds = []
-        for d in range(self.dim):
-            min_bound = min(self.r.component(d))
-            max_bound = max(self.r.component(d))
+        for dim in range(self.dim):
+            min_bound = min(self.r.component(dim))
+            max_bound = max(self.r.component(dim))
             _bounds.append((min_bound, max_bound))
         return _bounds
 
@@ -380,14 +431,6 @@ class Trajectory:
         in the velocity vector of the Trajectory."""
         return self.v.delta
 
-    @property
-    def delta_ang(self) -> Union[Vector, None]:
-        """Union[Vector, None] : Difference between each couple of
-        consecutive samples in the ``ang`` vector of the Trajectory."""
-        if self.ang is not None:
-            return self.ang.delta
-        return None
-
     def recalculate_velocity(self) -> Vector:
         """
         Recalculates the velocity according time data or `dt` if time
@@ -398,29 +441,13 @@ class Trajectory:
         Vector
             Velocity vector.
         """
-
-        self.__v = vel_estimators.estimate_velocity(self, **self.vel_est)
+        self.__v = diff.estimate_velocity(self, **self.diff_est)
         return self.__v
 
     @property
     def v(self) -> Vector:
         """Vector : Velocity vector"""
-        if self.__v is None:
-            method = self.vel_est["method"]
-            win_type = self.vel_est.get(
-                "window_type", vel_estimators.WindowType.CENTRAL
-            )
-            acc = self.vel_est.get("accuracy", 1)
-            acc_text = (
-                f" and accuracy {acc}"
-                if method == vel_estimators.VelocityMethod.FORNBERG_DIFF
-                else ""
-            )
-            raise ValueError(
-                f"Trajectory velocity can not be estimated using {method.name} "
-                f"method with window type {win_type.name}{acc_text}."
-            )
-        if self.lazy:
+        if self.lazy and self.__v is not None:
             return self.__v
         return self.recalculate_velocity()
 
@@ -428,18 +455,9 @@ class Trajectory:
     def t(self) -> Vector:
         """Vector : Time vector"""
         if self.__t is None:
-            dt_vec = [self.__t0 + self.dt * i for i in range(len(self))]
-            self.__t = Vector.create(dt_vec)
+            self.__t = Vector([self.t_0 + self.dt * i for i in range(len(self))])
         return self.__t
 
-    @property
-    def ang_velocity(self) -> Union[Vector, None]:
-        """Union[Vector, None] : Computes the angular velocity from the
-        ``ang`` vector of the Trajectory."""
-        if self.ang is not None:
-            return self.ang.delta / self.dt
-        return None
-
     def add_polar_offset(self, radius: float, angle: float) -> None:
         """
         Adds an offset given a point in polar coordinates.
@@ -456,26 +474,23 @@ class Trajectory:
         TypeError
             If the trajectory is not 2 dimensional.
         """
-
         if self.dim != 2:
             raise TypeError(
-                "Polar offsets can only be applied on 2 " "dimensional trajectories"
+                "Polar offsets can only be applied on 2 dimensional trajectories"
             )
 
         # From cartesian to polar
         x, y = self.r.x, self.r.y
-        rad = np.hypot(x, y)
-        ang = np.arctan2(y, x)
+        rad, ang = np.hypot(x, y), np.arctan2(y, x)
 
         rad += radius
         ang += angle
 
         # From polar to cartesian
-        x = rad * np.cos(ang)
-        y = rad * np.sin(ang)
-        self.r = Vector.create([x, y]).T
+        x, y = rad * np.cos(ang), rad * np.sin(ang)
+        self.r = Vector([x, y]).T
 
-    def rotate2d(self, angle: float):
+    def rotate_2d(self, angle: float):
         """
         Rotates the trajectory around the center coordinates [0,0]
 
@@ -486,13 +501,26 @@ class Trajectory:
         """
         self.add_polar_offset(0, angle)
 
-    def rotate3d(self, angle: float, vector: Union[list, np.ndarray]):
+    def rotate2d(self, angle: float):
+        """
+        .. deprecated:: 0.10.0
+            :func:`rotate2d` will be removed in a future version, use
+            :func:`rotate_2d` instead.
+        """
+        warnings.warn(
+            "rotate2d is deprecated and will be removed in a future version, "
+            "use rotate_2d instead",
+            DeprecationWarning,
+        )
+        self.rotate_2d(angle)
+
+    def rotate_3d(self, angle: float, vector: Collection[float]):
         """
         Rotates the trajectory around a given vector.
 
         Parameters
         ----------
-        vector : Vector
+        vector : Collection[float]
             Vector to rotate the trajectory around.
         angle : float
             Angle in radians to rotate the trajectory.
@@ -501,42 +529,55 @@ class Trajectory:
         ------
         TypeError
             If the trajectory is not 3 dimensional.
+        ValueError
+            If the vector has shape different than (3,).
         """
-
         if self.dim != 3:
             raise TypeError(
-                "3D rotations can only be applied on 3 " "dimensional trajectories"
+                "3D rotations can only be applied on 3 dimensional trajectories"
             )
 
-        vec: Vector = Vector.create(vector)
-        if len(vec) != 3:
-            raise ValueError("The vector must have 3 components")
+        vec = Vector(vector)
+        if vec.shape != (3,):
+            raise ValueError("The vector must have shape (3,)")
 
         vec = vec / vec.norm
-        vx, vy, vz = vec[0], vec[1], vec[2]
-        c, s = np.cos(angle), np.sin(angle)
+        v_x, v_y, v_z = vec[0], vec[1], vec[2]
+        a_cos, a_sin = np.cos(angle), np.sin(angle)
 
-        R = np.array(
+        rot_matrix = np.array(
             [
                 [
-                    vx * vx * (1 - c) + c,
-                    vx * vy * (1 - c) - vz * s,
-                    vx * vz * (1 - c) + vy * s,
+                    v_x * v_x * (1 - a_cos) + a_cos,
+                    v_x * v_y * (1 - a_cos) - v_z * a_sin,
+                    v_x * v_z * (1 - a_cos) + v_y * a_sin,
                 ],
                 [
-                    vx * vy * (1 - c) + vz * s,
-                    vy * vy * (1 - c) + c,
-                    vy * vz * (1 - c) - vx * s,
+                    v_x * v_y * (1 - a_cos) + v_z * a_sin,
+                    v_y * v_y * (1 - a_cos) + a_cos,
+                    v_y * v_z * (1 - a_cos) - v_x * a_sin,
                 ],
                 [
-                    vx * vz * (1 - c) - vy * s,
-                    vy * vz * (1 - c) + vx * s,
-                    vz * vz * (1 - c) + c,
+                    v_x * v_z * (1 - a_cos) - v_y * a_sin,
+                    v_y * v_z * (1 - a_cos) + v_x * a_sin,
+                    v_z * v_z * (1 - a_cos) + a_cos,
                 ],
             ]
         )
+        self.r = Vector(np.dot(self.r, rot_matrix))
 
-        self.r = Vector.create(np.dot(self.r, R))
+    def rotate3d(self, angle: float, vector: Union[list, np.ndarray]):
+        """
+        .. deprecated:: 0.10.0
+            :func:`rotate3d` will be removed in a future version, use
+            :func:`rotate_3d` instead.
+        """
+        warnings.warn(
+            "rotate3d is deprecated and will be removed in a future version, "
+            "use rotate_3d instead",
+            DeprecationWarning,
+        )
+        self.rotate_3d(angle, vector)
 
     def copy(self) -> Trajectory:
         """
@@ -547,27 +588,24 @@ class Trajectory:
         Trajectory
             Copy of the trajectory.
         """
-
         return Trajectory(
             points=self.r,
             t=self.__t,
-            ang=self.ang,
             dt=self.__dt,
             lazy=self.lazy,
-            vel_est=self.vel_est,
+            diff_est=self.diff_est,
         )
 
-    def _operable_with(self, other: Trajectory, threshold=None) -> bool:
-        if threshold is None:
-            threshold = _threshold
-
+    def _operable_with(
+        self, other: Trajectory, threshold: Optional[float] = None
+    ) -> bool:
         if self.r.shape != other.r.shape:
             return False
 
+        threshold = _THRESHOLD if threshold is None else threshold
         self_time = self.t
         other_time = other.t
-
-        diff = np.abs(self_time - other_time)
+        diff = np.abs(np.subtract(self_time, other_time))
         return all(diff < threshold)
 
     def __iadd__(self, other):
@@ -579,7 +617,7 @@ class Trajectory:
             offset = np.array(other, dtype=float)
             if len(offset) != self.dim:
                 raise ValueError(
-                    "Offset must be the same shape as the other " "trajectory points"
+                    "Offset must be the same shape as the other trajectory points"
                 )
             self.r += offset
             return self
@@ -604,7 +642,7 @@ class Trajectory:
             offset = np.array(other, dtype=float)
             if len(offset) != self.dim:
                 raise ValueError(
-                    "Offset must be the same shape as the other " "trajectory points"
+                    "Offset must be the same shape as the other trajectory points"
                 )
             self.r -= offset
             return self
@@ -640,7 +678,6 @@ class Trajectory:
         if isinstance(other, (int, float)):
             self.r *= other
             return self
-
         raise TypeError(
             "unsoported operation (*) between 'Trajectory' and "
             f"'{type(other).__name__}'"
@@ -687,10 +724,9 @@ class Trajectory:
             Turning angles where each position in the array correspond
             to a given time instant.
         """
-
-        dx = self.delta_r.x
-        dy = self.delta_r.y
-        theta = np.arctan2(dy, dx)
+        d_r = self.delta_r
+        d_x, d_y = d_r.x, d_r.y
+        theta = np.arctan2(d_y, d_x)
 
         if not accumulate:
             theta = np.ediff1d(theta)  # Relative turning angles
@@ -710,54 +746,45 @@ class Trajectory:
         discont_half = discont / 2
         return -((discont_half - theta) % discont - discont_half)
 
-    def _save_json(self, path: str):
-        def convert_to_list(vec: Vector):
+    def _save_json(self, path: Union[str, Path]) -> None:
+        def convert_to_list(vec: Optional[Vector]):
             if vec is None:
                 return vec
-
             if len(vec.shape) == 1:
                 return list(vec)
             return {d: list(v) for d, v in enumerate(vec)}
 
-        ang = None if self.ang is None else self.ang.T
-
-        default_vel_est_method = vel_estimators.VelocityMethod.LINEAR_DIFF
-        default_vel_est_window = vel_estimators.WindowType.CENTRAL
-        default_vel_est_accuracy = 1
-        vel_est = {
-            "method": self.vel_est.get("method", default_vel_est_method).value,
-            "window_type": self.vel_est.get("window", default_vel_est_window).value,
-            "accuracy": self.vel_est.get("accuracy", default_vel_est_accuracy),
+        diff_est = {
+            "method": self.diff_est.get("method", diff.DiffMethod.LINEAR_DIFF).value,
+            "window_type": self.diff_est.get("window", diff.WindowType.CENTRAL).value,
+            "accuracy": self.diff_est.get("accuracy", 1),
         }
 
         json_dict = {
             "id": self.traj_id,
             "dt": self.__dt,
             "r": convert_to_list(self.r.T),
-            "ang": convert_to_list(ang),
             "t": convert_to_list(self.__t),
-            "vel_est": vel_est,
+            "diff_est": diff_est,
         }
-        with open(str(path), "w") as traj_file:
+        with open(str(path), "w", encoding="utf-8") as traj_file:
             json.dump(json_dict, traj_file)
 
-    def _save_csv(self, path):
-        with open(str(path), "w", newline="") as traj_file:
+    def _save_csv(self, path: Union[str, Path]) -> None:
+        with open(str(path), "w", newline="", encoding="utf-8") as traj_file:
             writer = csv.writer(traj_file, delimiter=",")
-            ang_shape = 0 if self.ang is None else self.ang.shape[1]
-            writer.writerow([self.traj_id, self.__dt, self.dim, ang_shape])
+            writer.writerow([self.traj_id, self.__dt, self.dim])
 
-            default_vel_est_method = vel_estimators.VelocityMethod.LINEAR_DIFF
-            default_vel_est_window = vel_estimators.WindowType.CENTRAL
-            default_vel_est_accuracy = 1
-            method = self.vel_est.get("method", default_vel_est_method).value
-            window = self.vel_est.get("window", default_vel_est_window).value
-            accuracy = self.vel_est.get("accuracy", default_vel_est_accuracy)
-            print(method, window, accuracy)
+            default_diff_method = diff.DiffMethod.LINEAR_DIFF
+            default_diff_window = diff.WindowType.CENTRAL
+            default_diff_accuracy = 1
+            method = self.diff_est.get("method", default_diff_method).value
+            window = self.diff_est.get("window", default_diff_window).value
+            accuracy = self.diff_est.get("accuracy", default_diff_accuracy)
             writer.writerow([method, window, accuracy])
 
-            for tp in self:
-                row = np.hstack(np.array([tp.r, tp.ang, tp.t], dtype=object))
+            for t_p in self:
+                row = np.hstack([t_p.r, t_p.t])
                 writer.writerow(row)
 
     def save(
@@ -768,6 +795,10 @@ class Trajectory:
         overwrite: bool = True,
     ):
         """
+        .. deprecated:: 0.10.0
+            :func:`save` will be removed in a future version, use a Serializer
+            from ``yupi.core`` instead (e.g., JSONSerializer).
+
         Saves the trajectory to disk.
 
         Parameters
@@ -797,13 +828,18 @@ class Trajectory:
         >>> t = Trajectory(x=[0.37, 1.24, 1.5])
         >>> t.save('my_track')
         """
+        warnings.warn(
+            "`save` is deprecated and will be removed in a future version, use a "
+            "Serializer from `yupi.core` instead (e.g., JSONSerializer).",
+            DeprecationWarning,
+        )
 
         # Build full path
         full_path = Path(path) / Path(f"{file_name}.{file_type}")
 
         # Check file existance
         if not overwrite and full_path.exists():
-            raise ValueError(f"File '{str(full_path)}' already exist")
+            raise FileExistsError(f"File '{str(full_path)}' already exist")
 
         if file_type == "json":
             self._save_json(full_path)
@@ -814,7 +850,7 @@ class Trajectory:
 
     @staticmethod
     def save_trajectories(
-        trajectories: list,
+        trajs: List[Trajectory],
         folder_path: str = ".",
         file_type: str = "json",
         overwrite: bool = True,
@@ -825,12 +861,12 @@ class Trajectory:
 
         Parameters
         ----------
-        trajectories : list[Trajectory]
+        trajs : list[Trajectory]
             List of Trajectory objects that will be saved.
         folder_path : str
             Path where to save all the trajectory, by default ``'.'``.
         file_type : str
-            Type of the file, by default ``json``.
+            Type of the file, by default ``jon``.
 
             The only types avaliable are: ``json`` and ``csv``.
         overwrite : bool
@@ -840,69 +876,58 @@ class Trajectory:
         Examples
         --------
         >>> t1 = Trajectory(x=[0.37, 1.24, 1.5])
-        >>> t2 = Trajectory(x=[1, 2], y=[3, 4])
+        >>> t2 = Trajectory(x=[1, 2, 3], y=[3, 4, 5])
         >>> Trajectory.save_trajectories([t1, t2])
         """
-
-        for i, traj in enumerate(trajectories):
+        for i, traj in enumerate(trajs):
             path = str(Path(folder_path))
             name = str(Path(f"trajectory_{i}"))
             traj.save(name, path, file_type, overwrite)
 
     @staticmethod
     def _load_json(path: str):
-        with open(path, "r") as traj_file:
+        with open(path, "r", encoding="utf-8") as traj_file:
             data = json.load(traj_file)
 
             traj_id = data["id"]
-            dt = data["dt"]
-            t = data["t"]
-            ang = None
-
-            if data["ang"] is not None:
-                ang_values = list(data["ang"].values())
-                ang = Vector.create(ang_values).T
-
+            t, dt = data["t"], data["dt"]
             axes = list(data["r"].values())
-            vel_est = data.get("vel_est", None)
-            if vel_est is None:
-                vel_est = Trajectory.__vel_est
+            diff_est = data.get("diff_est", None)
+            if diff_est is None:
+                diff_est = Trajectory.general_diff_est
             else:
-                vel_est["method"] = vel_estimators.VelocityMethod(vel_est["method"])
-                vel_est["window_type"] = vel_estimators.WindowType(
-                    vel_est["window_type"]
-                )
+                diff_est["method"] = diff.DiffMethod(diff_est["method"])
+                diff_est["window_type"] = diff.WindowType(diff_est["window_type"])
 
-            return Trajectory(
-                axes=axes, t=t, ang=ang, dt=dt, traj_id=traj_id, vel_est=vel_est
-            )
+            return Trajectory(axes=axes, t=t, dt=dt, traj_id=traj_id, diff_est=diff_est)
 
     @staticmethod
     def _load_csv(path: str):
-        with open(path, "r") as traj_file:
+        with open(path, "r", encoding="utf-8") as traj_file:
 
-            def check_empty_val(val, cast=True):
+            def check_empty_val(val, cast_value=True) -> Union[None, float]:
                 if val == "":
                     return None
-                return float(val) if cast else val
+                return float(val) if cast_value else val
 
-            r, ang, t = [], [], []
-            traj_id, dt, dim = None, None, None
+            r: List[List[float]] = []
+            t: List[float] = []
+            traj_id: Optional[str] = None
+            dt, dim = 1.0, 1
+            diff_est = Trajectory.general_diff_est
 
             for i, row in enumerate(csv.reader(traj_file)):
                 if i == 0:
-                    traj_id = check_empty_val(row[0], cast=False)
+                    traj_id = row[0] if row[0] != "" else None
                     dt = check_empty_val(row[1])
                     dim = int(row[2])
-                    ang_dim = int(row[3])
                     r = [[] for _ in range(dim)]
-                    ang = [[] for _ in range(ang_dim)]
                     continue
 
                 if i == 1:
-                    vel_est = {
-                        "method": vel_estimators.VelocityMethod(int(row[0])),
-                        "window_type": vel_estimators.WindowType(int(row[1])),
+                    diff_est = {
+                        "method": diff.DiffMethod(int(row[0])),
+                        "window_type": diff.WindowType(int(row[1])),
                         "accuracy": int(row[2]),
                     }
                     continue
@@ -910,19 +935,17 @@ class Trajectory:
                 for j in range(dim):
                     r[j].append(float(row[j]))
 
-                for j, k in enumerate(range(dim, dim + ang_dim)):
-                    ang[j] = row[k]
-
                 t.append(float(row[-1]))
 
-            if not ang:
-                ang = None
-
-            return Trajectory(axes=r, t=t, ang=ang, dt=dt, traj_id=traj_id)
+            return Trajectory(axes=r, t=t, dt=dt, traj_id=traj_id, diff_est=diff_est)
 
     @staticmethod
     def load(file_path: str):
         """
+        .. deprecated:: 0.10.0
+            :func:`load` will be removed in a future version, use a Serializer
+            from ``yupi.core`` instead (e.g., JSONSerializer).
+
         Loads a trajectory
 
         Parameters
@@ -945,8 +968,13 @@ class Trajectory:
             If ``file_path`` extension is not ``json`` or ```csv``.
         """
 
-        path = Path(file_path)
+        warnings.warn(
+            "`load` is deprecated and will be removed in a future version, use a "
+            "Serializer from `yupi.core` instead (e.g., JSONSerializer).",
+            DeprecationWarning,
+        )
 
+        path = Path(file_path)
         # Check valid path
         if not path.exists():
             raise ValueError("Path does not exist.")
@@ -958,12 +986,11 @@ class Trajectory:
         try:
             if file_type == ".json":
                 return Trajectory._load_json(file_path)
-            elif file_type == ".csv":
+            if file_type == ".csv":
                 return Trajectory._load_csv(file_path)
-            else:
-                raise ValueError("Invalid file type.")
+            raise ValueError("Invalid file type.")
         except (json.JSONDecodeError, KeyError, ValueError, IndexError) as exc:
-            raise LoadTrajectoryError(path) from exc
+            raise LoadTrajectoryError(str(path)) from exc
 
     @staticmethod
     def load_folder(folder_path=".", recursively: bool = False):
@@ -983,15 +1010,14 @@ class Trajectory:
         List[Trajectory]
             List of the loaded trajectories.
         """
-
-        trajectories = []
+        trajs = []
         for root, _, files in os.walk(folder_path):
             for file in files:
                 path = str(Path(root) / Path(file))
                 try:
-                    trajectories.append(Trajectory.load(path))
+                    trajs.append(Trajectory.load(path))
                 except LoadTrajectoryError as load_exception:
-                    print(f"Ignoring: {load_exception.path}")
+                    logging.warning("Ignoring: '%s'", load_exception.path)
             if not recursively:
                 break
-        return trajectories
+        return trajs
